/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#define ACM1602_LCD_ADDRESS 0x50 // ACM1602 LCD アドレス

#define LCD_Char_1_ROW_0_START              (0x80u)
#define LCD_Char_1_ROW_1_START              (0xC0u)
#define LCD_Char_1_ROW_2_START              (0x94u)
#define LCD_Char_1_ROW_3_START              (0xD4u)

#define LCD_Char_1_DISPLAY_CURSOR_OFF       (0x08u)
#define LCD_Char_1_CLEAR_DISPLAY            (0x01u)
#define LCD_Char_1_CURSOR_AUTO_INCR_ON      (0x06u)
#define LCD_Char_1_DISPLAY_CURSOR_ON        (0x0Eu)
#define LCD_Char_1_DISPLAY_2_LINES_5x10     (0x2Cu)
#define LCD_Char_1_DISPLAY_ON_CURSOR_OFF    (0x0Cu)

#define LCD_Char_1_RESET_CURSOR_POSITION    (0x03u)
#define LCD_Char_1_CURSOR_WINK              (0x0Du)
#define LCD_Char_1_CURSOR_BLINK             (0x0Fu)
#define LCD_Char_1_CURSOR_SH_LEFT           (0x10u)
#define LCD_Char_1_CURSOR_SH_RIGHT          (0x14u)
#define LCD_Char_1_DISPLAY_SCRL_LEFT        (0x18u)
#define LCD_Char_1_DISPLAY_SCRL_RIGHT       (0x1Eu)
#define LCD_Char_1_CURSOR_HOME              (0x02u)
#define LCD_Char_1_CURSOR_LEFT              (0x04u)
#define LCD_Char_1_CURSOR_RIGHT             (0x06u)




//---------- LCD コマンド送信
void ACM1602_LCD_writeCmd(uint8_t cmd){
	I2C_I2CMasterSendStart(ACM1602_LCD_ADDRESS, I2C_I2C_WRITE_XFER_MODE ,1u);
	
	I2C_I2CMasterWriteByte(0x00, 1u);
	I2C_I2CMasterWriteByte(cmd, 1u);
	I2C_I2CMasterSendStop(1u);
}

//---------- LCD データ送信
void ACM1602_LCD_writeData(uint8_t data){
	I2C_I2CMasterSendStart(ACM1602_LCD_ADDRESS, I2C_I2C_WRITE_XFER_MODE ,1u);
	
	I2C_I2CMasterWriteByte(0x80, 1u);
	I2C_I2CMasterWriteByte(data, 1u);
	I2C_I2CMasterSendStop(1u);
}

//---------- LCD 初期化
void ACM1602_LCD_init(void){
	CyDelay(15);
	ACM1602_LCD_writeCmd(0x01);
	CyDelay(5);
	ACM1602_LCD_writeCmd(0x38);
	CyDelay(5);
	ACM1602_LCD_writeCmd(LCD_Char_1_DISPLAY_ON_CURSOR_OFF);
	CyDelay(5);
	ACM1602_LCD_writeCmd(LCD_Char_1_CURSOR_AUTO_INCR_ON);
}

//---------- LCD 文字列表示
void ACM1602_LCD_Char_PrintString(unsigned char *ACM1602_LCD_str){
	while( *ACM1602_LCD_str ){
		ACM1602_LCD_writeData(*ACM1602_LCD_str);
		ACM1602_LCD_str++;
	}
}

//---------- LCD ホームポジション
void ACM1602_LCD_homePosition(void){
	ACM1602_LCD_writeCmd(LCD_Char_1_CURSOR_HOME);
	CyDelay(2);
}

//---------- LCD 画面クリア（ホームポジション）
void ACM1602_LCD_clear(void){
	ACM1602_LCD_writeCmd(LCD_Char_1_CLEAR_DISPLAY);
	CyDelay(2);
}

//---------- LCD カーソルポジションポジション row=縦　colum=横
void ACM1602_LCD_position(uint8 row, uint8 column){
    switch (row)
    {
        case (uint8)0:
            ACM1602_LCD_writeCmd(LCD_Char_1_ROW_0_START + column);
            break;
        case (uint8) 1:
            ACM1602_LCD_writeCmd(LCD_Char_1_ROW_1_START + column);
            break;
        case (uint8) 2:
            ACM1602_LCD_writeCmd(LCD_Char_1_ROW_2_START + column);
            break;
        case (uint8) 3:
            ACM1602_LCD_writeCmd(LCD_Char_1_ROW_3_START + column);
            break;
        default:
            /* if default case is hit, invalid row argument was passed.*/
            break;
    }
}

//-------------------------------------------------------------------------//
unsigned char str1[]="Hello World";
unsigned char str2[]="PSoC4200M good";

int main(void)
{
    CyGlobalIntEnable; /* Enable global interrupts. */
	
	I2C_Start();
	ACM1602_LCD_init();
	ACM1602_LCD_position(0,0); 
	ACM1602_LCD_Char_PrintString(str1);

	ACM1602_LCD_position(1,0); 
	ACM1602_LCD_Char_PrintString(str2);
	
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */

    for(;;)
    {
        /* Place your application code here. */
		LED_Write(1);
		CyDelay(1000);
		LED_Write(0);
		CyDelay(1000);

    }
}

/* [] END OF FILE */
